@@ -209,6 +209,12 @@ oem <- function(x,
     hessian.type <- match.arg(hessian.type)
     
     dims <- dim(x)
+    
+    if (is.null(dims))
+    {
+        stop("x must have at least two columns")
+    }
+    
     n <- dims[1]
     p <- dims[2]
     
@@ -217,6 +223,11 @@ oem <- function(x,
         warning("oem() is optimized for n >> p settings and may be very slow when p > n")
     }
     
+    if (p < 2)
+    {
+        stop("x must have at least two columns")
+    }
+    
     y <- drop(y)
     y.vals <- unique(y)
     is.sparse <- FALSE
