@@ -161,6 +161,12 @@ xval.oem <- function(x,
     }
     
     dims <- dim(x)
+    
+    if (is.null(dims))
+    {
+        stop("x must have at least two columns")
+    }
+    
     n <- dims[1]
     p <- dims[2]
     
@@ -171,6 +177,11 @@ xval.oem <- function(x,
              glmnet for the lasso, ncvreg for MCP/SCAD, or grpreg or gglasso for group lasso.")
     }
     
+    if (p < 2)
+    {
+        stop("x must have at least two columns")
+    }
+    
     if (is.null(foldid)) 
         foldid = sample(rep(seq(nfolds), length = n))
     else nfolds = max(foldid)
